@@ -37,9 +37,8 @@ REDIRECT = {
     "excepthandler": "ExceptHandler",
     "keyword": "Keyword",
 }
-PY3 = sys.version_info >= (3, 0)
-PY34 = sys.version_info >= (3, 4)
 PY37 = sys.version_info >= (3, 7)
+PY38 = sys.version_info >= (3, 8)
 
 
 def _binary_operators_from_module(module):
@@ -50,6 +49,7 @@ def _binary_operators_from_module(module):
         module.BitXor: "^",
         module.Div: "/",
         module.FloorDiv: "//",
+        module.MatMult: "@",
         module.Mod: "%",
         module.Mult: "*",
         module.Pow: "**",
@@ -57,8 +57,6 @@ def _binary_operators_from_module(module):
         module.LShift: "<<",
         module.RShift: ">>",
     }
-    if sys.version_info >= (3, 5):
-        binary_operators[module.MatMult] = "@"
     return binary_operators
 
 
@@ -129,14 +127,17 @@ class TreeRebuilder:
             if PY37 and hasattr(node, "docstring"):
                 doc = node.docstring
                 return node, doc
-            if (
-                node.body
-                and isinstance(node.body[0], self._parser_module.Expr)
-                and isinstance(node.body[0].value, self._parser_module.Str)
-            ):
-                doc = node.body[0].value.s
-                node.body = node.body[1:]
-                return node, doc
+            if node.body and isinstance(node.body[0], self._parser_module.Expr):
+
+                first_value = node.body[0].value
+                if isinstance(first_value, self._parser_module.Str) or (
+                    PY38
+                    and isinstance(first_value, self._parser_module.Constant)
+                    and isinstance(first_value.value, str)
+                ):
+                    doc = first_value.value if PY38 else first_value.s
+                    node.body = node.body[1:]
+                    return node, doc
         except IndexError:
             pass  # ast built from scratch
         return node, None
@@ -179,57 +180,60 @@ class TreeRebuilder:
     def visit_arguments(self, node, parent):
         """visit an Arguments node by returning a fresh instance of it"""
         vararg, kwarg = node.vararg, node.kwarg
-        if PY34:
-            newnode = nodes.Arguments(
-                vararg.arg if vararg else None, kwarg.arg if kwarg else None, parent
-            )
-        else:
-            newnode = nodes.Arguments(vararg, kwarg, parent)
+        newnode = nodes.Arguments(
+            vararg.arg if vararg else None, kwarg.arg if kwarg else None, parent
+        )
         args = [self.visit(child, newnode) for child in node.args]
         defaults = [self.visit(child, newnode) for child in node.defaults]
         varargannotation = None
         kwargannotation = None
+        posonlyargs = []
         # change added in 82732 (7c5c678e4164), vararg and kwarg
         # are instances of `_ast.arg`, not strings
         if vararg:
-            if PY34:
-                if node.vararg.annotation:
-                    varargannotation = self.visit(node.vararg.annotation, newnode)
-                vararg = vararg.arg
+            if node.vararg.annotation:
+                varargannotation = self.visit(node.vararg.annotation, newnode)
+            vararg = vararg.arg
         if kwarg:
-            if PY34:
-                if node.kwarg.annotation:
-                    kwargannotation = self.visit(node.kwarg.annotation, newnode)
-                kwarg = kwarg.arg
-        if PY3:
-            kwonlyargs = [self.visit(child, newnode) for child in node.kwonlyargs]
-            kw_defaults = [
-                self.visit(child, newnode) if child else None
-                for child in node.kw_defaults
-            ]
-            annotations = [
+            if node.kwarg.annotation:
+                kwargannotation = self.visit(node.kwarg.annotation, newnode)
+            kwarg = kwarg.arg
+        kwonlyargs = [self.visit(child, newnode) for child in node.kwonlyargs]
+        kw_defaults = [
+            self.visit(child, newnode) if child else None for child in node.kw_defaults
+        ]
+        annotations = [
+            self.visit(arg.annotation, newnode) if arg.annotation else None
+            for arg in node.args
+        ]
+        kwonlyargs_annotations = [
+            self.visit(arg.annotation, newnode) if arg.annotation else None
+            for arg in node.kwonlyargs
+        ]
+
+        posonlyargs_annotations = []
+        if PY38:
+            posonlyargs = [self.visit(child, newnode) for child in node.posonlyargs]
+            posonlyargs_annotations = [
                 self.visit(arg.annotation, newnode) if arg.annotation else None
-                for arg in node.args
+                for arg in node.posonlyargs
             ]
-            kwonlyargs_annotations = [
-                self.visit(arg.annotation, newnode) if arg.annotation else None
-                for arg in node.kwonlyargs
-            ]
-        else:
-            kwonlyargs = []
-            kw_defaults = []
-            annotations = []
-            kwonlyargs_annotations = []
+        type_comment_args = [
+            self.check_type_comment(child, parent=newnode) for child in node.args
+        ]
 
         newnode.postinit(
             args=args,
             defaults=defaults,
             kwonlyargs=kwonlyargs,
+            posonlyargs=posonlyargs,
             kw_defaults=kw_defaults,
             annotations=annotations,
             kwonlyargs_annotations=kwonlyargs_annotations,
+            posonlyargs_annotations=posonlyargs_annotations,
             varargannotation=varargannotation,
             kwargannotation=kwargannotation,
+            type_comment_args=type_comment_args,
         )
         # save argument names in locals:
         if vararg:
@@ -248,7 +252,7 @@ class TreeRebuilder:
         newnode.postinit(self.visit(node.test, newnode), msg)
         return newnode
 
-    def check_type_comment(self, node):
+    def check_type_comment(self, node, parent):
         type_comment = getattr(node, "type_comment", None)
         if not type_comment:
             return None
@@ -259,7 +263,7 @@ class TreeRebuilder:
             # Invalid type comment, just skip it.
             return None
 
-        type_object = self.visit(type_comment_ast.body[0], node)
+        type_object = self.visit(type_comment_ast.body[0], parent=parent)
         if not isinstance(type_object, nodes.Expr):
             return None
 
@@ -287,8 +291,8 @@ class TreeRebuilder:
 
     def visit_assign(self, node, parent):
         """visit a Assign node by returning a fresh instance of it"""
-        type_annotation = self.check_type_comment(node)
         newnode = nodes.Assign(node.lineno, node.col_offset, parent)
+        type_annotation = self.check_type_comment(node, parent=newnode)
         newnode.postinit(
             targets=[self.visit(child, newnode) for child in node.targets],
             value=self.visit(node.value, newnode),
@@ -390,11 +394,10 @@ class TreeRebuilder:
         node, doc = self._get_doc(node)
         newnode = nodes.ClassDef(node.name, doc, node.lineno, node.col_offset, parent)
         metaclass = None
-        if PY3:
-            for keyword in node.keywords:
-                if keyword.arg == "metaclass":
-                    metaclass = self.visit(keyword, newnode).value
-                    break
+        for keyword in node.keywords:
+            if keyword.arg == "metaclass":
+                metaclass = self.visit(keyword, newnode).value
+                break
         if node.decorator_list:
             decorators = self.visit_decorators(node, newnode)
         else:
@@ -409,9 +412,7 @@ class TreeRebuilder:
                 self.visit(kwd, newnode)
                 for kwd in node.keywords
                 if kwd.arg != "metaclass"
-            ]
-            if PY3
-            else [],
+            ],
         )
         return newnode
 
@@ -457,7 +458,12 @@ class TreeRebuilder:
         """visit a Decorators node by returning a fresh instance of it"""
         # /!\ node is actually a _ast.FunctionDef node while
         # parent is an astroid.nodes.FunctionDef node
-        newnode = nodes.Decorators(node.lineno, node.col_offset, parent)
+        if PY38:
+            # Set the line number of the first decorator for Python 3.8+.
+            lineno = node.decorator_list[0].lineno
+        else:
+            lineno = node.lineno
+        newnode = nodes.Decorators(lineno, node.col_offset, parent)
         newnode.postinit([self.visit(child, newnode) for child in node.decorator_list])
         return newnode
 
@@ -546,7 +552,7 @@ class TreeRebuilder:
     def _visit_for(self, cls, node, parent):
         """visit a For node by returning a fresh instance of it"""
         newnode = cls(node.lineno, node.col_offset, parent)
-        type_annotation = self.check_type_comment(node)
+        type_annotation = self.check_type_comment(node, parent=newnode)
         newnode.postinit(
             target=self.visit(node.target, newnode),
             iter=self.visit(node.iter, newnode),
@@ -578,12 +584,24 @@ class TreeRebuilder:
         """visit an FunctionDef node to become astroid"""
         self._global_names.append({})
         node, doc = self._get_doc(node)
-        newnode = cls(node.name, doc, node.lineno, node.col_offset, parent)
+
+        lineno = node.lineno
+        if PY38 and node.decorator_list:
+            # Python 3.8 sets the line number of a decorated function
+            # to be the actual line number of the function, but the
+            # previous versions expected the decorator's line number instead.
+            # We reset the function's line number to that of the
+            # first decorator to maintain backward compatibility.
+            # It's not ideal but this discrepancy was baked into
+            # the framework for *years*.
+            lineno = node.decorator_list[0].lineno
+
+        newnode = cls(node.name, doc, lineno, node.col_offset, parent)
         if node.decorator_list:
             decorators = self.visit_decorators(node, newnode)
         else:
             decorators = None
-        if PY3 and node.returns:
+        if node.returns:
             returns = self.visit(node.returns, newnode)
         else:
             returns = None
@@ -896,7 +914,7 @@ class TreeRebuilder:
         else:
             optional_vars = None
 
-        type_annotation = self.check_type_comment(node)
+        type_annotation = self.check_type_comment(node, parent=newnode)
         newnode.postinit(
             items=[(expr, optional_vars)],
             body=[self.visit(child, newnode) for child in node.body],
@@ -1010,7 +1028,7 @@ class TreeRebuilder3(TreeRebuilder):
             var = _visit_or_none(child, "optional_vars", self, newnode)
             return expr, var
 
-        type_annotation = self.check_type_comment(node)
+        type_annotation = self.check_type_comment(node, parent=newnode)
         newnode.postinit(
             items=[visit_child(child) for child in node.items],
             body=[self.visit(child, newnode) for child in node.body],
@@ -1061,6 +1079,12 @@ class TreeRebuilder3(TreeRebuilder):
         )
         return newnode
 
+    def visit_namedexpr(self, node, parent):
+        newnode = nodes.NamedExpr(node.lineno, node.col_offset, parent)
+        newnode.postinit(
+            self.visit(node.target, newnode), self.visit(node.value, newnode)
+        )
+        return newnode
 
-if sys.version_info >= (3, 0):
-    TreeRebuilder = TreeRebuilder3
+
+TreeRebuilder = TreeRebuilder3
